==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ComputeStartStopScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ComputePowerAction
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ScheduleStatus
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.TriggerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Compute start stop schedule properties
 * @property action [Required] The compute power action.
 * @property cron Required if triggerType is Cron.
 * @property recurrence Required if triggerType is Recurrence.
 * @property schedule [Deprecated] Not used any more.
 * @property status Is the schedule enabled or disabled?
 * @property triggerType [Required] The schedule trigger type.
 */
public data class ComputeStartStopScheduleArgs(
    public val action: Output<Either<String, ComputePowerAction>>? = null,
    public val cron: Output<CronArgs>? = null,
    public val recurrence: Output<RecurrenceArgs>? = null,
    public val schedule: Output<ScheduleBaseArgs>? = null,
    public val status: Output<Either<String, ScheduleStatus>>? = null,
    public val triggerType: Output<Either<String, TriggerType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .cron(cron?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .recurrence(recurrence?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .schedule(schedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .triggerType(
                triggerType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ComputeStartStopScheduleArgs].
 */
@PulumiTagMarker
public class ComputeStartStopScheduleArgsBuilder internal constructor() {
    private var action: Output<Either<String, ComputePowerAction>>? = null

    private var cron: Output<CronArgs>? = null

    private var recurrence: Output<RecurrenceArgs>? = null

    private var schedule: Output<ScheduleBaseArgs>? = null

    private var status: Output<Either<String, ScheduleStatus>>? = null

    private var triggerType: Output<Either<String, TriggerType>>? = null

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("hxoarmsyfebaxfaa")
    public suspend fun action(`value`: Output<Either<String, ComputePowerAction>>) {
        this.action = value
    }

    /**
     * @param value Required if triggerType is Cron.
     */
    @JvmName("bxwrkhrgldorkdia")
    public suspend fun cron(`value`: Output<CronArgs>) {
        this.cron = value
    }

    /**
     * @param value Required if triggerType is Recurrence.
     */
    @JvmName("bskcptulxnkyekvf")
    public suspend fun recurrence(`value`: Output<RecurrenceArgs>) {
        this.recurrence = value
    }

    /**
     * @param value [Deprecated] Not used any more.
     */
    @JvmName("vcvlkcrgygauvsqh")
    public suspend fun schedule(`value`: Output<ScheduleBaseArgs>) {
        this.schedule = value
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("omujxxjrbosyfxmg")
    public suspend fun status(`value`: Output<Either<String, ScheduleStatus>>) {
        this.status = value
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("xthksyjyequnlbvb")
    public suspend fun triggerType(`value`: Output<Either<String, TriggerType>>) {
        this.triggerType = value
    }

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("sshgisxjnnabwxhp")
    public suspend fun action(`value`: Either<String, ComputePowerAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("dtqpsfowgticimea")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ComputePowerAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("gwpjlsnocysbdsvi")
    public fun action(`value`: ComputePowerAction) {
        val toBeMapped = Either.ofRight<String, ComputePowerAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Required if triggerType is Cron.
     */
    @JvmName("liuebixypgysxvay")
    public suspend fun cron(`value`: CronArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cron = mapped
    }

    /**
     * @param argument Required if triggerType is Cron.
     */
    @JvmName("viwjxwmmvpjhwagk")
    public suspend fun cron(argument: suspend CronArgsBuilder.() -> Unit) {
        val toBeMapped = CronArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.cron = mapped
    }

    /**
     * @param value Required if triggerType is Recurrence.
     */
    @JvmName("kxqtypeidsnkluyv")
    public suspend fun recurrence(`value`: RecurrenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recurrence = mapped
    }

    /**
     * @param argument Required if triggerType is Recurrence.
     */
    @JvmName("nuxesklbhitrkxtj")
    public suspend fun recurrence(argument: suspend RecurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = RecurrenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.recurrence = mapped
    }

    /**
     * @param value [Deprecated] Not used any more.
     */
    @JvmName("vaahtrmkukllrhru")
    public suspend fun schedule(`value`: ScheduleBaseArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schedule = mapped
    }

    /**
     * @param argument [Deprecated] Not used any more.
     */
    @JvmName("nojhcpajroquonfk")
    public suspend fun schedule(argument: suspend ScheduleBaseArgsBuilder.() -> Unit) {
        val toBeMapped = ScheduleBaseArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("rqrdijougkxlrckh")
    public suspend fun status(`value`: Either<String, ScheduleStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("bjiqfcktrbyhnkho")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ScheduleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("nyjtslegbjqmfccw")
    public fun status(`value`: ScheduleStatus) {
        val toBeMapped = Either.ofRight<String, ScheduleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("nkdojmavarkuousn")
    public suspend fun triggerType(`value`: Either<String, TriggerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("sfwodmkaabyfrchu")
    public fun triggerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("frpqxychipiiobfj")
    public fun triggerType(`value`: TriggerType) {
        val toBeMapped = Either.ofRight<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    internal fun build(): ComputeStartStopScheduleArgs = ComputeStartStopScheduleArgs(
        action = action,
        cron = cron,
        recurrence = recurrence,
        schedule = schedule,
        status = status,
        triggerType = triggerType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/machinelearningservices/kotlin/inputs/ComputeStartStopScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.machinelearningservices.kotlin.inputs

import com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs.builder
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ComputePowerAction
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.ScheduleStatus
import com.pulumi.azurenative.machinelearningservices.kotlin.enums.TriggerType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Compute start stop schedule properties
 * @property action [Required] The compute power action.
 * @property cron Required if triggerType is Cron.
 * @property recurrence Required if triggerType is Recurrence.
 * @property schedule [Deprecated] Not used any more.
 * @property status Is the schedule enabled or disabled?
 * @property triggerType [Required] The schedule trigger type.
 */
public data class ComputeStartStopScheduleArgs(
    public val action: Output<Either<String, ComputePowerAction>>? = null,
    public val cron: Output<CronArgs>? = null,
    public val recurrence: Output<RecurrenceArgs>? = null,
    public val schedule: Output<ScheduleBaseArgs>? = null,
    public val status: Output<Either<String, ScheduleStatus>>? = null,
    public val triggerType: Output<Either<String, TriggerType>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs> {
    override fun toJava():
        com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs =
        com.pulumi.azurenative.machinelearningservices.inputs.ComputeStartStopScheduleArgs.builder()
            .action(
                action?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .cron(cron?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .recurrence(recurrence?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .schedule(schedule?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .triggerType(
                triggerType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ComputeStartStopScheduleArgs].
 */
@PulumiTagMarker
public class ComputeStartStopScheduleArgsBuilder internal constructor() {
    private var action: Output<Either<String, ComputePowerAction>>? = null

    private var cron: Output<CronArgs>? = null

    private var recurrence: Output<RecurrenceArgs>? = null

    private var schedule: Output<ScheduleBaseArgs>? = null

    private var status: Output<Either<String, ScheduleStatus>>? = null

    private var triggerType: Output<Either<String, TriggerType>>? = null

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("cdantkbyobjnxgnn")
    public suspend fun action(`value`: Output<Either<String, ComputePowerAction>>) {
        this.action = value
    }

    /**
     * @param value Required if triggerType is Cron.
     */
    @JvmName("qwahrquotaajnnjr")
    public suspend fun cron(`value`: Output<CronArgs>) {
        this.cron = value
    }

    /**
     * @param value Required if triggerType is Recurrence.
     */
    @JvmName("lseuaykaylqeuttp")
    public suspend fun recurrence(`value`: Output<RecurrenceArgs>) {
        this.recurrence = value
    }

    /**
     * @param value [Deprecated] Not used any more.
     */
    @JvmName("ljssleghtwqcfakn")
    public suspend fun schedule(`value`: Output<ScheduleBaseArgs>) {
        this.schedule = value
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("ofsegpiamhjbxvlx")
    public suspend fun status(`value`: Output<Either<String, ScheduleStatus>>) {
        this.status = value
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("peffckujyigpgbcw")
    public suspend fun triggerType(`value`: Output<Either<String, TriggerType>>) {
        this.triggerType = value
    }

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("wvtginpmqgrtwkye")
    public suspend fun action(`value`: Either<String, ComputePowerAction>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("bmqcvlvuyysvpvvh")
    public fun action(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ComputePowerAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value [Required] The compute power action.
     */
    @JvmName("rvhyxwwitjqrucnq")
    public fun action(`value`: ComputePowerAction) {
        val toBeMapped = Either.ofRight<String, ComputePowerAction>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.action = mapped
    }

    /**
     * @param value Required if triggerType is Cron.
     */
    @JvmName("eyxccjjendynoktn")
    public suspend fun cron(`value`: CronArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cron = mapped
    }

    /**
     * @param argument Required if triggerType is Cron.
     */
    @JvmName("vavddxwgleqfdrcq")
    public suspend fun cron(argument: suspend CronArgsBuilder.() -> Unit) {
        val toBeMapped = CronArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.cron = mapped
    }

    /**
     * @param value Required if triggerType is Recurrence.
     */
    @JvmName("dkwtjorukhfmdywl")
    public suspend fun recurrence(`value`: RecurrenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.recurrence = mapped
    }

    /**
     * @param argument Required if triggerType is Recurrence.
     */
    @JvmName("taqfuttltghxggiy")
    public suspend fun recurrence(argument: suspend RecurrenceArgsBuilder.() -> Unit) {
        val toBeMapped = RecurrenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.recurrence = mapped
    }

    /**
     * @param value [Deprecated] Not used any more.
     */
    @JvmName("aygkphollbtlbfro")
    public suspend fun schedule(`value`: ScheduleBaseArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.schedule = mapped
    }

    /**
     * @param argument [Deprecated] Not used any more.
     */
    @JvmName("bspjasnygnihjcde")
    public suspend fun schedule(argument: suspend ScheduleBaseArgsBuilder.() -> Unit) {
        val toBeMapped = ScheduleBaseArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.schedule = mapped
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("gjbppdsvkpfulbcq")
    public suspend fun status(`value`: Either<String, ScheduleStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("vyeddyrarjvhpgrt")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ScheduleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Is the schedule enabled or disabled?
     */
    @JvmName("ldndaakbnfasuyeu")
    public fun status(`value`: ScheduleStatus) {
        val toBeMapped = Either.ofRight<String, ScheduleStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("lyvyywitpwfysnag")
    public suspend fun triggerType(`value`: Either<String, TriggerType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("rswtgcuvreclyllx")
    public fun triggerType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    /**
     * @param value [Required] The schedule trigger type.
     */
    @JvmName("mgbbxqukhnuuhroc")
    public fun triggerType(`value`: TriggerType) {
        val toBeMapped = Either.ofRight<String, TriggerType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.triggerType = mapped
    }

    internal fun build(): ComputeStartStopScheduleArgs = ComputeStartStopScheduleArgs(
        action = action,
        cron = cron,
        recurrence = recurrence,
        schedule = schedule,
        status = status,
        triggerType = triggerType,
    )
}
